@@ -33,10 +33,12 @@
     https://www.starlette.io/authentication/
     https://github.com/amitripshtos/starlette-jwt
 
-"""
+    TODO: Response for Auth errors like WRONG_PASSWD, SUSPENDED_FAILS is 200 with STATUS OK, should be HTTP Exception 401,403.
 
+"""
 from datetime import datetime, timezone
 import bcrypt
+import jwt
 from starlette.routing import Route
 from dl2050utils.core import oget
 from dl2050utils.com import send_otp
@@ -114,17 +116,19 @@ class Auth():
         if res:
             log_and_raise_service(self.LOG, label='AUTH', label2=prefix, msg='DB update error')
 
-    async def enforce_find_user(self, d, label2='', msg='User not found'):
+    async def enforce_find_user(self, d, label2=''):
         user = await self.db.select_one('users', d)
         if user is None:
-            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg=msg)
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='User not found', status_code=401)
+        if user['ustatus']!=ACTIVE:
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='User not active', status_code=403)
         return user
 
-    async def enforce_admin_perm(self, request, label2='', msg='User without admim authorization', requires_su=False):
-        user = await self.enforce_find_user({'id':request.user.display_name}, label2=label2, msg='Admin user not found')
+    async def enforce_admin_perm(self, request, label2='', requires_su=False):
+        user = await self.enforce_find_user({'id':request.user.display_name}, label2=label2)
         role,org = user['role'],user['org']
         if user['ustatus']!=ACTIVE or role not in ['su', 'admin'] or (requires_su==True and role!='su'):
-            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg=msg)
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg=f'{label2}: User is not admin', status_code=403)
         return role,org
 
     async def increase_fails(self, user, fail='LOGIN'):
@@ -215,12 +219,23 @@ class Auth():
 
     async def check_auth(self, request):
         """
-            Used by App to check for valid user token, through the valid decription of request.user.display_name.
-            If the JWT is valid, the user info is returned, otherwise an exception is raises through enforce_find_user.
+            Used by App to check for valid user JWT token, through the valid decription of request.user.display_name.
+            If the JWT is valid, the user email checks and the status is ACTIVE, the user info is returned.
+            Otherwise an exception is raised.
             Response must be a dict, not json, since it is an internal method.
+            TODO: transfer this logic to a custom class of AuthenticationBackend -> enforce through @requires('authenticated')
         """
-        uid = request.user.display_name
-        user = await self.enforce_find_user({'id':uid}, label2=f'check_auth for {uid}')
+        label2 = 'check_auth'
+        if not hasattr(request.user, 'display_name') or not hasattr(request.user, 'payload'):
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='Invalid JWT token', status_code=401)
+        uid,payload = request.user.display_name,request.user.payload
+        user = await self.db.select_one('users', {'id':uid})
+        if user is None:
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='User not found', status_code=401)
+        if user['email']!=payload['email']:
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='User email mistatch', status_code=401)
+        if user['ustatus']!=ACTIVE:
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='User not active', status_code=403)
         return get_user_info(user)
     
     async def get_email_from_uid(self, uid):
@@ -247,14 +262,17 @@ class Auth():
             Checks if a user if able to login, searching its status by user email given as input.
             To be used before asking for password in the login process.
             Returns auth_status and users_status, searching by user email.
-            Possible auth_status returns: 'USER_OK', 'WAIT_SET_PASSWD', 'USER_SUSPENDED', 'USER_NOT_REGISTERED'
+            Possible auth_status returns: 'USER_OK', 'WAIT_SET_PASSWD'.
+            Possible exception messages: 'USER_NOT_REGISTERED', 'USER_SUSPENDED'
             If Auth is not configured for self register and the user does exist, innitiates the OTP process.
         """
+        label2 = 'check_user'
         data = await request.json()
-        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2='check_user', as_list=True)
+        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2=label2, as_list=True)
         user = await self.db.select_one('users', {'email':email})
         if user is None:
-            return self.ret(auth_status='USER_NOT_REGISTERED')
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_NOT_REGISTERED', status_code=401)
+            # return self.ret(auth_status='USER_NOT_REGISTERED')
         if user['ustatus']==ACTIVE:
             increase(user, 'logins')
             await self.db_update('users', 'email', user, 'check_user')
@@ -264,7 +282,10 @@ class Auth():
         if user['ustatus']==NOT_REGISTERED and not self.allow_register:
             await self.gen_otp(user)
             return self.ret(auth_status='WAIT_SET_PASSWD')
-        return self.ret(auth_status='USER_SUSPENDED', user_status=user['ustatus'])
+        if user['ustatus'] in [SUSPENDED, SUSPENDED_LICENCE, SUSPENDED_FAILS, SUSPENDED_REQUESTS]:
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_SUSPENDED', status_code=403)
+        log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='UNKNOWN STATUS', status_code=403)
+        # return self.ret(auth_status='USER_SUSPENDED', user_status=user['ustatus'])
 
     async def check_otp(self, request):
         """
@@ -276,22 +297,26 @@ class Auth():
             Possible auth_status returns: 'SET_PASSWD_DONE', 'OTP_OK', 'OTP_ERROR', 'USER_SUSPENDED', 'WAIT_SET_PASSWD_TIMEOUT,
             'WAIT_SET_PASSWD_SUSPENDED'
         """
+        label2 = 'check_otp'
         data = await request.json()
-        [email,otp] = enforce_required_args(self.LOG, data, ['email','otp'], label='AUTH', label2='check_otp', as_list=True)
-        user = await self.enforce_find_user({'email':email}, label2='set_passwd')
+        [email,otp] = enforce_required_args(self.LOG, data, ['email','otp'], label='AUTH', label2=label2, as_list=True)
+        user = await self.enforce_find_user({'email':email}, label2=label2)
         if user['ustatus']==ACTIVE:
             return self.ret(auth_status='SET_PASSWD_DONE', user_status=user['ustatus'])
         if user['ustatus'] in [SUSPENDED, SUSPENDED_LICENCE, SUSPENDED_FAILS, SUSPENDED_REQUESTS]:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_SUSPENDED', status_code=403)
             return self.ret(auth_status='USER_SUSPENDED', user_status=user['ustatus'])
         if otp!=user['otp']:
-            self.LOG(3, 0, label='AUTH', label2='check_otp', msg=f"OTP error: {user['email']}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"OTP error: {user['email']}")
             if await self.increase_fails(user, 'OTP'):
                 return self.ret(auth_status='WAIT_SET_PASSWD_SUSPENDED')
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='OTP_ERROR', status_code=403)
             return self.ret(auth_status='OTP_ERROR')
         delta = get_age_in_seconds(user['ts_passwd'])
         if delta > self.otp_timeout:
-            self.LOG(3, 0, label='AUTH', label2='OTP', msg=f"OTP expired: {user['email']} (delta={delta})")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"OTP expired: {user['email']} (delta={delta})")
             await self.gen_otp(user)
+            # log_and_raise_service(self.LOG, label='AUTH', msg='WAIT_SET_PASSWD_TIMEOUT', status_code=401)
             return self.ret(auth_status='WAIT_SET_PASSWD_TIMEOUT')
         return self.ret(auth_status='OTP_OK')
 
@@ -301,24 +326,29 @@ class Auth():
             Possible auth_status returns: 'SET_PASSWD_DONE', 'USER_SUSPENDED', 'WAIT_SET_PASSWD_SUSPENDED', 'OTP_ERROR',
             'WAIT_SET_PASSWD_TIMEOUT, 'PASSWD_NOT_STRONG', 'SET_PASSWD_OK'
         """
+        label2 = 'set_passwd'
         data = await request.json()
-        [email,otp,passwd] = enforce_required_args(self.LOG, data, ['email','otp','passwd'], label='AUTH', label2='recover_passwd', as_list=True)
-        user = await self.enforce_find_user({'email':email}, label2='set_passwd')
+        [email,otp,passwd] = enforce_required_args(self.LOG, data, ['email','otp','passwd'], label='AUTH', label2=label2, as_list=True)
+        user = await self.enforce_find_user({'email':email}, label2=label2)
         if user['ustatus']==ACTIVE:
             return self.ret(auth_status='SET_PASSWD_DONE')
         if user['ustatus'] in [SUSPENDED, SUSPENDED_LICENCE, SUSPENDED_FAILS, SUSPENDED_REQUESTS]:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_SUSPENDED', status_code=401)
             return self.ret(auth_status='USER_SUSPENDED', user_status=user['ustatus'])
         if otp!=user['otp']:
-            self.LOG(3, 0, label='AUTH', label2='check_otp', msg=f"OTP error: {user['email']}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"OTP error: {user['email']}")
             if await self.increase_fails(user, 'OTP'):
+                # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='WAIT_SET_PASSWD_SUSPENDED', status_code=403)
                 return self.ret(auth_status='WAIT_SET_PASSWD_SUSPENDED')
             return self.ret(auth_status='OTP_ERROR')
         delta = get_age_in_seconds(user['ts_passwd'])
         if delta > self.otp_timeout:
-            self.LOG(3, 0, label='AUTH', label2='OTP', msg=f"OTP expired: {user['email']} (delta={delta})")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"OTP expired: {user['email']} (delta={delta})")
             await self.gen_otp(user)
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='WAIT_SET_PASSWD_TIMEOUT', status_code=403)
             return self.ret(auth_status='WAIT_SET_PASSWD_TIMEOUT')
         if not check_passwd_strengh(passwd):
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='PASSWD_NOT_STRONG', status_code=403)
             return self.ret(auth_status='PASSWD_NOT_STRONG')
         hashed = bcrypt.hashpw(passwd.encode(), bcrypt.gensalt())
         user['passwd'],user['ts_passwd'],user['otp'],user['ustatus'] = hashed.decode(),datetime.now(timezone.utc),'',ACTIVE
@@ -335,23 +365,28 @@ class Auth():
             Possible auth_status returns: 'USER_NOT_REGISTERED', 'NOT_AUTHORIZED', 'PASSWD_NOT_STRONG', 'SUSPENDED_FAILS',
             'WRONG_PASSWD, 'AUTHORIZED'
         """
+        label2 = 'login'
         data = await request.json()
-        [email,passwd] = enforce_required_args(self.LOG, data, ['email', 'passwd'], label='AUTH', label2='login', as_list=True)
+        [email,passwd] = enforce_required_args(self.LOG, data, ['email', 'passwd'], label='AUTH', label2=label2, as_list=True)
         user = await self.db.select_one('users', {'email':email})
         if user is None:
-            self.LOG(3, 0, label='AUTH', label2='login', msg=f"User not registered: {email}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"User not registered: {email}")
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_NOT_REGISTERED', status_code=401)
             return self.ret(auth_status='USER_NOT_REGISTERED')
         if user['ustatus']!=ACTIVE:
-            self.LOG(3, 0, label='AUTH', label2='login', msg=f"User not active: {user['email']}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"User not active: {user['email']}")
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='NOT_AUTHORIZED', status_code=403)
             return self.ret(auth_status='NOT_AUTHORIZED', user_status=user['ustatus'])
         # if not check_passwd_strengh(passwd):
         #     return self.ret(auth_status='PASSWD_NOT_STRONG')
         if not bcrypt.checkpw(passwd.encode(), user['passwd'].encode()):
-            self.LOG(3, 0, label='AUTH', label2='login', msg=f"WRONG PASSWORD: {user['email']}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"WRONG PASSWORD: {user['email']}")
             if await self.increase_fails(user, 'LOGIN'):
-                self.LOG(3, 0, label='AUTH', label2='login', msg=f"Too many LOGIN FAILS: {user['email']} - USER SUSPENDED")
+                self.LOG(3, 0, label='AUTH', label2=label2, msg=f"Too many LOGIN FAILS: {user['email']} - USER SUSPENDED")
+                # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='SUSPENDED_FAILS', status_code=403)
                 return self.ret(auth_status='SUSPENDED_FAILS', user_status=user['ustatus'])
-            self.LOG(3, 0, label='AUTH', label2='login', msg=f"LOGIN FAIL: {user['email']}")    
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"LOGIN FAIL: {user['email']}")
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='WRONG_PASSWD', status_code=403)
             return self.ret(auth_status='WRONG_PASSWD')
         jwt_token = mk_jwt_token(user['id'], email, self.auth_secret)
         increase(user, 'logins', True)
@@ -364,15 +399,17 @@ class Auth():
             Set user mode in WAIT_SET_PASSWD and send new OTP
             Possible auth_status returns: 'USER_NOT_ACTIVE', 'WAIT_SET_PASSWD'
         """
+        label2 = 'recover_passwd'
         data = await request.json()
-        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2='recover_passwd', as_list=True)
-        user = await self.enforce_find_user({'email':email}, label2='recover_passwd')
+        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2=label2, as_list=True)
+        user = await self.enforce_find_user({'email':email}, label2=label2)
         if user['ustatus']==WAIT_SET_PASSWD:
             return self.ret(auth_status='WAIT_SET_PASSWD')
         if user['ustatus']!=ACTIVE:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_NOT_ACTIVE', status_code=403)
             return self.ret(auth_status='USER_NOT_ACTIVE')
         user['ustatus'] = WAIT_SET_PASSWD
-        await self.db_update('users', 'email', user, 'recover_passwd')
+        await self.db_update('users', 'email', user, label2)
         await self.gen_otp(user)
         return self.ret(auth_status='WAIT_SET_PASSWD')
 
@@ -381,21 +418,26 @@ class Auth():
             Changes a logged in user password
             Possible auth_status returns: 'USER_NOT_ACTIVE', 'PASSWD_NOT_STRONG', 'SUSPENDED_FAILS', 'WRONG_PASSWD', 'CHANGE_PASSWD_OK'
         """
-        user = await self.enforce_find_user({'id':request.user.display_name}, label2='change_passwd')
+        label2 = 'change_passwd'
+        user = await self.enforce_find_user({'id':request.user.display_name}, label2=label2)
         if user['ustatus']==WAIT_SET_PASSWD:
             return self.ret(auth_status='WAIT_SET_PASSWD')
         if user['ustatus']!=ACTIVE:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_NOT_ACTIVE', status_code=403)
             return self.ret(auth_status='USER_NOT_ACTIVE')
         data = await request.json()
-        [passwd,new_passwd] = enforce_required_args(self.LOG, data, ['passwd','new_passwd'], label='AUTH', label2='recover_passwd', as_list=True)
+        [passwd,new_passwd] = enforce_required_args(self.LOG, data, ['passwd','new_passwd'], label='AUTH', label2=label2, as_list=True)
         if not check_passwd_strengh(new_passwd):
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='PASSWD_NOT_STRONG', status_code=403)
             return self.ret(auth_status='PASSWD_NOT_STRONG')
         if not bcrypt.checkpw(passwd.encode(), user['passwd'].encode()):
-            self.LOG(3, 0, label='AUTH', label2='change_passwd', msg=f"WRONG PASSWORD: {user['email']}")
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"WRONG PASSWORD: {user['email']}")
             if await self.increase_fails(user, 'LOGIN'):
-                self.LOG(3, 0, label='AUTH', label2='login', msg=f"Too many LOGIN FAILS: {user['email']} - USER SUSPENDED")
+                self.LOG(3, 0, label='AUTH', label2=label2, msg=f"Too many LOGIN FAILS: {user['email']} - USER SUSPENDED")
+                # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='SUSPENDED_FAILS', status_code=403)
                 return self.ret(auth_status='SUSPENDED_FAILS', user_status=user['ustatus'])
-            self.LOG(3, 0, label='AUTH', label2='login', msg=f"LOGIN FAIL: {user['email']}")    
+            self.LOG(3, 0, label='AUTH', label2=label2, msg=f"LOGIN FAIL: {user['email']}")
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='WRONG_PASSWD', status_code=403)
             return self.ret(auth_status='WRONG_PASSWD')
         hashed = bcrypt.hashpw(new_passwd.encode(), bcrypt.gensalt())
         user['passwd'],user['otp'],user['ustatus'] = hashed.decode(),'',ACTIVE
@@ -407,22 +449,25 @@ class Auth():
             Registers a new user, eithe in self register mode or admin pre-register
             Possible auth_status returns: 'USER_ALREADY_REGISTERED', 'WAIT_SET_PASSWD', 'REGISTER_OK'
         """
+        label2 = 'register'
         org = None
         data = await request.json()
-        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2='recover_passwd', as_list=True)
+        [email] = enforce_required_args(self.LOG, data, ['email'], label='AUTH', label2=label2, as_list=True)
         user2 = {'email':email, 'role':'user', 'ts_insert':datetime.now(timezone.utc), 'logins':0, 'fails':0, 'requests':0}
         user = await self.db.select_one('users', {'email':email})
         # Self registration
         if self.allow_register:
             if user is not None:
+                # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_ALREADY_REGISTERED', status_code=401)
                 return self.ret(auth_status='USER_ALREADY_REGISTERED')
             user2['ustatus'] = WAIT_SET_PASSWD
             await self.db.insert('users', user2)
             self.gen_otp(user)
             return self.ret(auth_status='WAIT_SET_PASSWD')
         # Registration of new user by admin or su
-        role,org = await self.enforce_admin_perm(request, label2='register')
+        role,org = await self.enforce_admin_perm(request, label2=label2)
         if user is not None:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='USER_ALREADY_REGISTERED', status_code=401)
             return self.ret(auth_status='USER_ALREADY_REGISTERED')
         user2['org'] = user['org'] if role=='admin' else org
         user2['ustatus'] = NOT_REGISTERED
@@ -434,9 +479,10 @@ class Auth():
     # ####################################################################################################
 
     async def get_users(self, request):
-        """ Get all users, possibly filtered by filters """
+        """Get all users, possibly filtered by filters."""
+        label2 = 'get_users'
         data = await request.json()
-        role,org = await self.enforce_admin_perm(request, label2='get_users')
+        role,org = await self.enforce_admin_perm(request, label2=label2)
         data = await request.json()
         QARGS = ['cols','filters','sfilters','sort','ascending','offset','limit']
         kwargs = {k:data[k] for k in data if k in QARGS}
@@ -445,40 +491,46 @@ class Auth():
         kwargs['filters'] = filters
         res = await self.db.select('users', **kwargs)
         if res is None or not 'data' in res or not 'nrows' in res:
-            log_and_raise_service(self.LOG, label='AUTH', label2='get_users', msg='DB access error')
+            log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='DB access error')
         return rest_ok({'data':res['data'], 'nrows':res['nrows']})
 
     async def update_user(self, request):
-        """ Updates user data """
-        role,org = await self.enforce_admin_perm(request, label2='update_user')
+        """Update user data."""
+        label2 = 'update_user'
+        role,org = await self.enforce_admin_perm(request, label2=label2)
         data = await request.json()
-        user = await self.enforce_find_user({'id': data['id']}, label2='update_user')
+        user = await self.enforce_find_user({'id': data['id']}, label2=label2)
         if role=='admin' and user['org']!=org:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='NOT_AUTHORIZED', status_code=403)
             return self.ret(auth_status='NOT_AUTHORIZED')
-        await self.db_update('users', 'id', data, 'update_user')
+        await self.db_update('users', 'id', data, label2)
         return rest_ok()
 
     async def reset_user(self, request):
-        """ Resets user to SET_NEW_PASSWORD mode and reset fails. """
-        role,org = await self.enforce_admin_perm(request, label2='reset_user')
+        """Reset user to SET_NEW_PASSWORD mode and reset fails."""
+        label2 = 'reset_user'
+        role,org = await self.enforce_admin_perm(request, label2=label2)
         data = await request.json()
-        user = await self.enforce_find_user({'id': data['id']}, label2='reset_user')
+        user = await self.enforce_find_user({'id': data['id']}, label2=label2)
         if role=='admin' and user['org']!=org:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='NOT_AUTHORIZED', status_code=403)
             return self.ret(auth_status='NOT_AUTHORIZED')
         user['ustatus'],user['fails'],user['otp'] = 0,0,None
-        await self.db_update('users', 'id', user, 'reset_user')
+        await self.db_update('users', 'id', user, label2)
         return rest_ok()
 
     async def suspend_user(self, request):
-        """ Suspends a user changing ustatus to SUSPENDED or to SUSPENDED_LICENCE if data['ustatus']==SUSPENDED_LICENCE. """
-        role,org = await self.enforce_admin_perm(request, label2='suspend_user')
+        """Suspend a user changing ustatus to SUSPENDED or to SUSPENDED_LICENCE if data['ustatus']==SUSPENDED_LICENCE."""
+        label2 = 'suspend_user'
+        role,org = await self.enforce_admin_perm(request, label2=label2)
         data = await request.json()
-        user = await self.enforce_find_user({'id': data['id']}, label2='suspend_user')
+        user = await self.enforce_find_user({'id': data['id']}, label2=label2)
         if role=='admin' and user['org']!=org:
+            # log_and_raise_service(self.LOG, label='AUTH', label2=label2, msg='NOT_AUTHORIZED', status_code=403)
             return self.ret(auth_status='NOT_AUTHORIZED')
         ustatus = int(data['ustatus']) if 'ustatus' in data and int(data['ustatus'])==SUSPENDED_LICENCE else SUSPENDED
         user['ustatus'] = ustatus
-        await self.db_update('users', 'id', user, 'suspend_user')
+        await self.db_update('users', 'id', user, label2)
         return rest_ok()
 
     # ####################################################################################################
@@ -486,9 +538,10 @@ class Auth():
     # ####################################################################################################
 
     async def change_org(self, request):
-        """ Change su org """
-        _,_ = await self.enforce_admin_perm(request, label2='change_org', requires_su=True)
-        user = await self.enforce_find_user({'id':request.user.display_name}, label2='change_org')
+        """Change su org."""
+        label2 = 'change_org'
+        _,_ = await self.enforce_admin_perm(request, label2=label2, requires_su=True)
+        user = await self.enforce_find_user({'id':request.user.display_name}, label2=label2)
         data = await request.json()
         user['org'] = data['org']
         jwt_token = mk_jwt_token(user['id'], user['email'], self.auth_secret)
@@ -496,10 +549,11 @@ class Auth():
         return rest_ok({'jwt_token':jwt_token, 'user_info':get_user_info(user)})
 
     async def su(self, request):
-        """ Switch uid """
-        _,_ = await self.enforce_admin_perm(request, label2='su', requires_su=True)
+        """Switch uid."""
+        label2 = 'su'
+        _,_ = await self.enforce_admin_perm(request, label2=label2, requires_su=True)
         data = await request.json()
-        [uid] = enforce_required_args(self.LOG, data, ['uid'], label='AUTH', label2='su', as_list=True)
-        user = await self.enforce_find_user({'id':uid}, label2='su')
+        [uid] = enforce_required_args(self.LOG, data, ['uid'], label='AUTH', label2=label2, as_list=True)
+        user = await self.enforce_find_user({'id':uid}, label2=label2)
         jwt_token = mk_jwt_token(user['id'], user['email'], self.auth_secret)
         return rest_ok({'jwt_token':jwt_token, 'user_info':get_user_info(user)})
